Skip to contents

Return semantic group color mappings

Usage

group_colors(dictionary = "default", overrides = NULL)

Arguments

dictionary

A named dictionary such as "default". Domain-specific example dictionaries are still available for backward compatibility but are not listed unless available_group_dictionaries(include_examples = TRUE) is used. You may also pass a named override vector as the first argument, which applies on top of the default dictionary.

overrides

Optional named vector of color overrides.

Value

A named character vector.