Return semantic group color mappings
Arguments
- dictionary
A named dictionary such as
"default". Domain-specific example dictionaries are still available for backward compatibility but are not listed unlessavailable_group_dictionaries(include_examples = TRUE)is used. You may also pass a named override vector as the first argument, which applies on top of the default dictionary.- overrides
Optional named vector of color overrides.